OC.L10N.register(
    "groupfolders",
    {
    "Access denied" : "Acceso denegado",
    "Group" : "Grupo",
    "Read" : "Leer",
    "Write" : "Escribir",
    "Create" : "Crear",
    "Delete" : "Borrar",
    "Share" : "Compartir",
    "You" : "Tú",
    "Add group" : "Agregar grupo",
    "Unlimited" : "Ilimitado",
    "Delete \"{folderName}\"?" : "Borrar \"{folderName}\"?",
    "Folder name" : "Nombre de la carpeta",
    "Quota" : "Cuota",
    "Previous" : "Previo",
    "User" : "Ususario",
    "Unknown" : "Desconocido",
    "None" : "Ninguno",
    "{size} used" : "{size} usado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
